function kalman_demo0()

% Assume simple model 
%   x[n+1] = x[n]
%   y[n+1] = y[n]
%   pos = [x,y]'
A = [ 1 0 ; 0 1 ];
B = [ 0; 0 ];
C = [ 1 0 ; 0 1 ];
D = [ 0; 0 ];
% Initial covariances
P0 = diag([10, 10]);  % initial process noise, decreses exponentially
% We believe in the model
% Q = diag([0.00001,0.00001]);    % process noise
% R = diag([100,100]);            % measurement noise
% We believe in the model
% Q = diag([1,1]); % process noise
% R = [1;1];       % measurement noise
% We believe in measurement
Q = diag([1,1]);          % process noise
R = diag([1,1]);      % measurement noise

% Generate GPS coordinates
coords = gps_generator0();

% Allocate
filt_history = zeros(size(coords'));
pred_history = zeros(size(coords'));

% State is a column vector!
x0 = coords(1,:)';

% Loop over measured data
for n=1:size(coords,1)
  % Generate synthetic measurement
  % Again, measurements are a column vector...
  ym = coords(n,:)';
  % Update model state vector based on the old one and measurement
  [x0f,x1p,P0f,P1p]=kalman(x0,0,ym,A,B,C,D,P0,Q,R);
  % Record the filtered state
  filt_history(:,n) = x0f;
  % Record the prediction
  pred_history(:,n) = x1p;
  % The updated state will be the "old" state in the next step
  x0 = x1p;
  % The updated state noise will be the "old" state noise in the next step
  P0 = P1p;
end

% Draw it
figure(1);
plot(coords(:,1),coords(:,2),'.b', ...
     filt_history(1,:),filt_history(2,:),'-r', ...
     pred_history(1,:),pred_history(2,:),'-g');
xlabel('xm');
ylabel('ym');