function f_data = window_filter(data, weights)

    % Size of the filtering window
    window_size = length(weights);
    % Normalize weights so that tey sum to 1
    weights = weights./sum(weights);
    % How many data records do we have to process?
    num_data = length(data);
    % Initialize the output. Matlab does copy-on-assignment.
    f_data = data;
    % Loop over all data records that we can process, e.g.
    % records that do have data available for the full filtering 
    % window.
    for i=window_size:num_data
        % (a) scale every value in the window by its weight
        %     e.g. [ 1 1 1 1 1 ] => [ 1/5 1/5 1/5 1/5 1/5 ]
        % (b) sum them to get the filtered value
        %     e.g. [ 1/5 1/5 1/5 1/5 1/5 ] => 1
        f_data(i) = sum(weights .* data((i-window_size+1):i));
    end
end